@@ -54,7 +54,7 @@ def data_path(filename):
     return os.path.join(data_dir, filename)
 
 # Test Case: A Seyfert 1 galaxy
-coords = coordinates.ICRS('0h8m05.63s +14d50m23.3s')
+coords = coordinates.SkyCoord('0h8m05.63s +14d50m23.3s')
 
 ALFALFA = alfalfa.core.Alfalfa()
 
