@@ -10,8 +10,10 @@ import keyring
 import numpy as np
 import re
 import tarfile
+import string
 from bs4 import BeautifulSoup
 
+from astropy.extern.six.moves.urllib_parse import urljoin
 from astropy.extern.six import BytesIO,iteritems
 from astropy.extern import six
 from astropy.table import Table, Column
@@ -63,7 +65,7 @@ class AlmaClass(QueryWithLogin):
 
         if payload is None:
             payload = {}
-        payload.update({'source_name_sesame': object_name,})
+        payload.update({'source_name_resolver': object_name,})
 
         return self.query_async(payload, cache=cache, public=public,
                                 science=science, **kwargs)
@@ -97,7 +99,7 @@ class AlmaClass(QueryWithLogin):
 
         if payload is None:
             payload = {}
-        payload.update({'raDecCoordinates': rdc})
+        payload.update({'ra_dec': rdc})
 
         return self.query_async(payload, cache=cache, public=public,
                                 science=science, **kwargs)
@@ -120,13 +122,14 @@ class AlmaClass(QueryWithLogin):
             Return only data marked as "science" in the archive?
         """
 
-        url = os.path.join(self._get_dataarchive_url(), 'aq', 'search.votable')
+        url = urljoin(self._get_dataarchive_url(), 'aq/')
 
-        payload.update({'viewFormat':'raw',})
+        payload.update({'result_view':'raw', 'format':'VOTABLE',
+                        'download':'true'})
         if public:
-            payload['publicFilterFlag'] = 'public'
+            payload['public_data'] = 'public'
         if science:
-            payload['scan_intent-asu'] = '=*TARGET*'
+            payload['science_observations'] = '=%TARGET%'
 
         self.validate_query(payload)
 
@@ -178,16 +181,18 @@ class AlmaClass(QueryWithLogin):
                 self.dataarchive_url = self.archive_url
         return self.dataarchive_url
 
-    def stage_data(self, uids, cache=False):
+    def stage_data(self, uids):
         """
         Stage ALMA data
 
         Parameters
         ----------
-        uids : list
-            A list of valid UIDs.
+        uids : list or str
+            A list of valid UIDs or a single UID.
             UIDs should have the form: 'uid://A002/X391d0b/X7b'
-        cache : bool
+        cache : True
+            This is *forced* true, because the ALMA servers don't support repeats
+            of the same request.
             Whether to cache the staging process.  This should generally be
             left as False when used interactively.
 
@@ -198,30 +203,50 @@ class AlmaClass(QueryWithLogin):
             downloading), and the file size
         """
 
+        """
+        With log.set_level(10)
+        INFO: Staging files... [astroquery.alma.core]
+        DEBUG: First request URL: https://almascience.eso.org/rh/submission [astroquery.alma.core]
+        DEBUG: First request payload: {'dataset': [u'ALMA+uid___A002_X3b3400_X90f']} [astroquery.alma.core]
+        DEBUG: First response URL: https://almascience.eso.org/rh/checkAuthenticationStatus/3f98de33-197e-4692-9afa-496842032ea9/submission [astroquery.alma.core]
+        DEBUG: Request ID: 3f98de33-197e-4692-9afa-496842032ea9 [astroquery.alma.core]
+        DEBUG: Submission URL: https://almascience.eso.org/rh/submission/3f98de33-197e-4692-9afa-496842032ea9 [astroquery.alma.core]
+        .DEBUG: Data list URL: https://almascience.eso.org/rh/requests/anonymous/786823226 [astroquery.alma.core]
+        """
+
+        if isinstance(uids, six.string_types):
+            uids = [uids]
+        if not isinstance(uids, (list, tuple, np.ndarray)):
+            raise TypeError("Datasets must be given as a list of strings.")
+
         log.info("Staging files...")
 
         self._get_dataarchive_url()
 
-        url = os.path.join(self.dataarchive_url, 'rh', 'submission')
+        url = urljoin(self.dataarchive_url, 'rh/submission')
         log.debug("First request URL: {0}".format(url))
         #'ALMA+uid___A002_X391d0b_X7b'
         #payload = [('dataset','ALMA+'+clean_uid(uid)) for uid in uids]
         payload = {'dataset':['ALMA+'+clean_uid(uid) for uid in uids]}
         log.debug("First request payload: {0}".format(payload))
 
-        self._staging_log = {}
+        self._staging_log = {'first_post_url':url}
 
         # Request staging for the UIDs
+        # This component cannot be cached, since the returned data can change
+        # if new data are uploaded
         response = self._request('POST', url, data=payload,
-                                 timeout=self.TIMEOUT, cache=cache)
+                                 timeout=self.TIMEOUT, cache=False)
         self._staging_log['initial_response'] = response
         log.debug("First response URL: {0}".format(response.url))
         response.raise_for_status()
 
         if 'j_spring_cas_security_check' in response.url:
             time.sleep(1)
+            # CANNOT cache this stage: it not a real data page!  results in
+            # infinite loops
             response = self._request('POST', url, data=payload,
-                                     timeout=self.TIMEOUT, cache=cache)
+                                     timeout=self.TIMEOUT, cache=False)
             self._staging_log['initial_response'] = response
             if 'j_spring_cas_security_check' in response.url:
                 log.warn("Staging request was not successful.  Try again?")
@@ -233,12 +258,12 @@ class AlmaClass(QueryWithLogin):
         log.debug("Request ID: {0}".format(request_id))
 
         # Submit a request for the specific request ID identified above
-        submission_url = os.path.join(self.dataarchive_url, 'rh', 'submission',
-                                      request_id)
+        submission_url = urljoin(self.dataarchive_url,
+                                 os.path.join('rh/submission', request_id))
         log.debug("Submission URL: {0}".format(submission_url))
         self._staging_log['submission_url'] = submission_url
         has_completed = False
-        staging_submission = self._request('GET', submission_url, cache=cache)
+        staging_submission = self._request('GET', submission_url, cache=True)
         self._staging_log['staging_submission'] = staging_submission
         staging_submission.raise_for_status()
 
@@ -249,7 +274,8 @@ class AlmaClass(QueryWithLogin):
 
         while not has_completed:
             time.sleep(1)
-            data_page = self._request('GET', data_page_url, cache=cache)
+            # CANNOT cache this step: please_wait will happen infinitely
+            data_page = self._request('GET', data_page_url, cache=False)
             if 'Please wait' not in data_page.text:
                 has_completed = True
             print(".",end='')
@@ -264,35 +290,15 @@ class AlmaClass(QueryWithLogin):
         self._staging_log['data_list_url'] = data_list_url
 
         time.sleep(1)
-        data_list_page = self._request('GET', data_list_url, cache=cache)
+        data_list_page = self._request('GET', data_list_url, cache=True)
         self._staging_log['data_list_page'] = data_list_page
         data_list_page.raise_for_status()
 
-        root = BeautifulSoup(data_list_page.content, 'html5lib')
-
         if 'Error' in data_list_page.text:
             errormessage = root.find('div', id='errorContent').string.strip()
             raise RemoteServiceError(errormessage)
 
-        data_table = root.findAll('table', class_='list', id='report')[0]
-        columns = {'uid':[], 'URL':[], 'size':[]}
-        for tr in data_table.findAll('tr'):
-            tds = tr.findAll('td')
-            if len(tds) > 1 and 'uid' in tds[1].text:
-                uid = tds[1].text.strip()
-            if len(tds) > 3 and tds[2].find('a'):
-                href = tds[2].find('a')
-                size,unit = re.search('([0-9\.]*)([A-Za-z]*)', tds[3].text).groups()
-                columns['uid'].append(uid)
-                columns['URL'].append(href.attrs['href'])
-                unit = (u.Unit(unit) if unit in ('GB','MB')
-                        else u.Unit('kB') if 'kb' in unit.lower()
-                        else 1)
-                columns['size'].append(float(size)*u.Unit(unit))
-
-        columns['size'] = u.Quantity(columns['size'], u.Gbyte)
-
-        tbl = Table([Column(name=k, data=v) for k,v in iteritems(columns)])
+        tbl = self._parse_staging_request_page(data_list_page)
 
         return tbl
 
@@ -339,8 +345,8 @@ class AlmaClass(QueryWithLogin):
 
         Parameters
         ----------
-        uids : list
-            A list of valid UIDs.
+        uids : list or str
+            A list of valid UIDs or a single UID.
             UIDs should have the form: 'uid://A002/X391d0b/X7b'
         cache : bool
             Whether to cache the downloads.
@@ -376,7 +382,7 @@ class AlmaClass(QueryWithLogin):
         tf = six.BytesIO(response.content)
         vo_tree = votable.parse(tf, pedantic=False, invalid='mask')
         first_table = vo_tree.get_first_table()
-        table = first_table.to_table()
+        table = first_table.to_table(use_names_over_ids=True)
         return table
 
     def _login(self, username, store_password=False):
@@ -409,8 +415,8 @@ class AlmaClass(QueryWithLogin):
 
         login_response = self._request("POST", "https://asa.alma.cl/cas/login",
                                        params={'service':
-                                               os.path.join(self.archive_url,
-                                                            'rh', 'login')},
+                                               urljoin(self.archive_url,
+                                                       'rh/login')},
                                        data=data,
                                        cache=False)
 
@@ -443,8 +449,8 @@ class AlmaClass(QueryWithLogin):
                         if cycle0id in row['ID']]
             return contents
         else:
-            info_url = os.path.join(self._get_dataarchive_url(),
-                                    'documents-and-tools/cycle-2/ALMAQA2Productsv1.01.pdf')
+            info_url = urljoin(self._get_dataarchive_url(),
+                               'documents-and-tools/cycle-2/ALMAQA2Productsv1.01.pdf')
             raise ValueError("Not a Cycle 0 UID.  See {0} for details about"
                              " cycle 1+ data release formats.".format(info_url))
 
@@ -454,8 +460,8 @@ class AlmaClass(QueryWithLogin):
         In principle, this is a static file, but we'll retrieve it just in case
         """
         if not hasattr(self, '_cycle0_tarfile_content_table'):
-            url = os.path.join(self._get_dataarchive_url(),
-                               'alma-data/archive/cycle-0-tarfile-content')
+            url = urljoin(self._get_dataarchive_url(),
+                          'alma-data/archive/cycle-0-tarfile-content')
             response = self._request('GET', url, cache=True)
 
             # html.parser is needed because some <tr>'s have form:
@@ -482,8 +488,8 @@ class AlmaClass(QueryWithLogin):
         Stoehr.
         """
         if not hasattr(self,'_cycle0_table'):
-            filename = os.path.join(os.path.dirname(__file__), 'data',
-                                    'cycle0_delivery_asdm_mapping.txt')
+            filename = urljoin(os.path.dirname(__file__),
+                               'data/cycle0_delivery_asdm_mapping.txt')
             self._cycle0_table = Table.read(filename, format='ascii.no_header')
             self._cycle0_table.rename_column('col1', 'ID')
             self._cycle0_table.rename_column('col2', 'uid')
@@ -532,7 +538,7 @@ class AlmaClass(QueryWithLogin):
                         log.info("Extracting {0} to {1}".format(member.name,
                                                                 path))
                     tf.extract(member, path)
-                    filelist.append(os.path.join(path, member.name))
+                    filelist.append(urljoin(path, member.name))
 
         return filelist
 
@@ -550,6 +556,8 @@ class AlmaClass(QueryWithLogin):
 
         Parameters
         ----------
+        urls : str or list
+            A single URL or a list of URLs
         include_asdm : bool
             Only affects cycle 1+ data.  If set, the ASDM files will be
             downloaded in addition to the script and log files.  By default,
@@ -557,6 +565,12 @@ class AlmaClass(QueryWithLogin):
             any information: you must change the regex if you want to extract
             data from an ASDM tarball
         """
+
+        if isinstance(urls, six.string_types):
+            urls = [urls]
+        if not isinstance(urls, (list, tuple, np.ndarray)):
+            raise TypeError("Datasets must be given as a list of strings.")
+
         all_files = []
         for url in urls:
             if url[-4:] != '.tar':
@@ -601,10 +615,15 @@ class AlmaClass(QueryWithLogin):
             print()
             print(title)
             for row in section:
-                if len(row) == 2:
+                if len(row) == 2: # text value
                     name,payload_keyword = row
                     print("  {0:33s}: {1:35s}".format(name,payload_keyword))
-                elif len(row) == 4:
+                #elif len(row) == 3: # radio button
+                #    name,payload_keyword,value = row
+                #    print("  {0:33s}: {1:20s} = {2:15s}".format(name,
+                #                                                    payload_keyword,
+                #                                                    value))
+                elif len(row) == 4: # radio button or checkbox
                     name,payload_keyword,checkbox,value = row
                     print("  {2} {0:29s}: {1:20s} = {3:15s}".format(name,
                                                                     payload_keyword,
@@ -621,32 +640,59 @@ class AlmaClass(QueryWithLogin):
             root = BeautifulSoup(querypage.content)
             sections = root.findAll('td', class_='category')
 
+            whitespace = re.compile("\s+")
+
             help_list = []
             for section in sections:
                 title = section.find('div', class_='categorytitle').text.lstrip()
                 help_section = (title,[])
                 for inp in section.findAll('div', class_='inputdiv'):
                     sp = inp.find('span')
-                    if sp is not None:
-                        payload_keyword = sp.attrs['class'][0]
-                        name = sp.text
-                        help_section[1].append((name,payload_keyword))
-                    else:
-                        buttons = inp.findAll('input')
-                        for b in buttons:
-                            payload_keyword = b.attrs['name']
-                            bid = b.attrs['id']
-                            label = inp.find('label')
+                    buttons = inp.findAll('input')
+                    for b in buttons:
+                        # old version:for=id=rawView; name=viewFormat
+                        # new version:for=id=rawView; name=result_view
+                        payload_keyword = b.attrs['name']
+                        bid = b.attrs['id']
+                        label = inp.find('label')
+                        if sp is not None:
+                            name = whitespace.sub(" ", sp.text)
+                        elif label.attrs['for'] == bid:
+                            name = whitespace.sub(" ", label.text)
+                        else:
+                            raise TableParseError("ALMA query page has"
+                                                  " an unrecognized entry")
+                        if b.attrs['type'] == 'text':
+                            help_section[1].append((name, payload_keyword))
+                        elif b.attrs['type'] == 'radio':
+                            value = b.attrs['value']
+                            if 'checked' in b.attrs:
+                                checked = b.attrs['checked'] == 'checked'
+                                checkbox = "(x)" if checked else "( )"
+                            else:
+                                checkbox = "( )"
+                            help_section[1].append((name, payload_keyword,
+                                                    checkbox, value))
+                        elif b.attrs['type'] == 'checkbox':
                             checked = b.attrs['checked'] == 'checked'
                             value = b.attrs['value']
-                            if label.attrs['for'] == bid:
-                                name = label.text
-                            else:
-                                raise TableParseError("ALMA query page has"
-                                                      " an unrecognized entry")
                             checkbox = "[x]" if checked else "[ ]"
                             help_section[1].append((name, payload_keyword,
                                                     checkbox, value))
+                    select = inp.find('select')
+                    if select is not None:
+                        options = [(filter_printable(option.text),
+                                    option.attrs['value'])
+                                   for option in select.findAll('option')]
+                        if sp is not None:
+                            name = whitespace.sub(" ", sp.text)
+                        else:
+                            name = select.attrs['name']
+                        option_str = " , ".join(["{0} = {1}".format(o[0],o[1])
+                                                 for o in options])
+                        help_section[1].append((name, option_str))
+
+
                 help_list.append(help_section)
             self._help_list = help_list
 
@@ -654,16 +700,153 @@ class AlmaClass(QueryWithLogin):
 
     def _validate_payload(self, payload):
         if not hasattr(self, '_valid_params'):
-            help_list = self._get_help_page()
+            help_list = self._get_help_page(cache=False)
             self._valid_params = [row[1]
                                   for title,section in help_list
                                   for row in section]
+            # These parameters are entirely hidden, but Felix says they are
+            # allowed
+            self._valid_params.append('download')
+            self._valid_params.append('format')
         invalid_params = [k for k in payload if k not in self._valid_params]
         if len(invalid_params) > 0:
             raise InvalidQueryError("The following parameters are not accepted "
                                     "by the ALMA query service:"
                                     " {0}".format(invalid_params))
 
+    def _parse_staging_request_page(self, data_list_page):
+        """
+        Parse pages like this one:
+        https://almascience.eso.org/rh/requests/anonymous/786572566
+
+        that include links to data sets that have been requested and staged
+
+        Parameters
+        ----------
+        data_list_page : requests.Response object
+
+        """
+
+        root = BeautifulSoup(data_list_page.content, 'html5lib')
+
+        #for link in root.findAll('a'):
+        #    if 'script.sh' in link.text:
+        #        download_script_url = urljoin(self.dataarchive_url,
+        #                                      link['href'])
+        #if 'download_script_url' not in locals():
+        #    raise RemoteServiceError("No download links were found.")
+
+        #download_script = self._request('GET', download_script_url,
+        #                                cache=False)
+        #download_script_target_urls = []
+        #for line in download_script.text.split('\n'):
+        #    if line and line.split() and line.split()[0] == 'wget':
+        #        download_script_target_urls.append(line.split()[1].strip('"'))
+
+        #if len(download_script_target_urls) == 0:
+        #    raise RemoteServiceError("There was an error parsing the download "
+        #                             "script; it is empty.  "
+        #                             "You can access the download script "
+        #                             "directly from this URL: "
+        #                             "{0}".format(download_script_url))
+
+        data_table = root.findAll('table', class_='list', id='report')[0]
+        columns = {'uid':[], 'URL':[], 'size':[]}
+        for tr in data_table.findAll('tr'):
+            tds = tr.findAll('td')
+
+            # Cannot check class if it is not defined
+            cl = 'class' in tr.attrs
+
+            if len(tds) > 1 and 'uid' in tds[0].text and (cl and
+                                                          'Level' in tr['class'][0]):
+                # New Style
+                text = tds[0].text.strip().split()
+                if text[0] in ('Asdm', 'Member'):
+                    uid = text[-1]
+            elif len(tds) > 1 and 'uid' in tds[1].text:
+                # Old Style
+                uid = tds[1].text.strip()
+            elif cl and tr['class'] == 'Level_1':
+                raise ValueError("A heading was found when parsing the download page but "
+                                 "it was not parsed correctly")
+
+            if len(tds) > 3 and (cl and tr['class'][0] == 'fileRow'):
+                # New Style
+                size,unit = re.search('(-|[0-9\.]*)([A-Za-z]*)', tds[2].text).groups()
+                href = tds[1].find('a')
+                if size == '':
+                    # this is a header row
+                    continue
+                authorized = ('access_authorized.png' in tds[3].findChild('img')['src'])
+                if authorized:
+                    columns['uid'].append(uid)
+                    if href and 'href' in href.attrs:
+                        columns['URL'].append(href.attrs['href'])
+                    else:
+                        columns['URL'].append('None_Found')
+                    unit = (u.Unit(unit) if unit in ('GB','MB')
+                            else u.Unit('kB') if 'kb' in unit.lower()
+                            else 1)
+                    try:
+                        columns['size'].append(float(size)*u.Unit(unit))
+                    except ValueError: 
+                        # size is probably a string?
+                        columns['size'].append(-1*u.byte)
+                    log.log(level=5, msg="Found a new-style entry.  "
+                            "size={0} uid={1} url={2}".format(size, uid,
+                                                              columns['URL'][-1]))
+                else:
+                    log.warn("Access to {0} is not authorized.".format(uid))
+            elif len(tds) > 3 and tds[2].find('a'):
+                # Old Style
+                href = tds[2].find('a')
+                size,unit = re.search('([0-9\.]*)([A-Za-z]*)', tds[3].text).groups()
+                columns['uid'].append(uid)
+                columns['URL'].append(href.attrs['href'])
+                unit = (u.Unit(unit) if unit in ('GB','MB')
+                        else u.Unit('kB') if 'kb' in unit.lower()
+                        else 1)
+                columns['size'].append(float(size)*u.Unit(unit))
+                log.log(level=5, msg="Found an old-style entry.  "
+                        "size={0} uid={1} url={2}".format(size, uid,
+                                                          columns['URL'][-1]))
+
+        columns['size'] = u.Quantity(columns['size'], u.Gbyte)
+
+        if len(columns['uid']) == 0:
+            raise RemoteServiceError("No valid UIDs were found in the staged "
+                                     "data table.  Please include {0} "
+                                     "in a bug report."
+                                     .format(self._staging_log['data_list_url']))
+
+        #if len(download_script_target_urls) != len(columns['URL']):
+        #    log.warn("There was an error parsing the data staging page.  "
+        #             "The results from the page and the download script "
+        #             "differ.  You can access the download script directly "
+        #             "from this URL: {0}".format(download_script_url))
+        #else:
+        #    bad_urls = []
+        #    for (rurl,url) in (zip(columns['URL'],
+        #                           download_script_target_urls)):
+        #        if rurl == 'None_Found':
+        #            url_uid = os.path.split(url)[-1]
+        #            ind = np.where(np.array(columns['uid']) == url_uid)[0][0]
+        #            columns['URL'][ind] = url
+        #        elif rurl != url:
+        #            bad_urls.append((rurl, url))
+        #    if bad_urls:
+        #        log.warn("There were mismatches between the parsed URLs "
+        #                 "from the staging page ({0}) and the download "
+        #                 "script ({1})."
+        #                 .format(self._staging_log['data_list_url'],
+        #                         download_script_url))
+
+        tbl = Table([Column(name=k, data=v) for k,v in iteritems(columns)])
+
+
+        return tbl
+
 Alma = AlmaClass()
 
 def clean_uid(uid):
@@ -688,3 +871,44 @@ def unique(seq):
     seen = set()
     seen_add = seen.add
     return [x for x in seq if not (x in seen or seen_add(x))]
+
+def filter_printable(s):
+    """ extract printable characters from a string """
+    return filter(lambda x: x in string.printable, s)
+
+def parse_frequency_support(frequency_support_str):
+    """
+    ALMA "Frequency Support" strings have the form:
+    [100.63..101.57GHz,488.28kHz, XX YY] U [102.43..103.37GHz,488.28kHz, XX YY] U [112.74..113.68GHz,488.28kHz, XX YY] U [114.45..115.38GHz,488.28kHz, XX YY]
+    at least, as far as we have seen.  The "U" is meant to be the Union symbol.
+    This function will parse such a string into a list of pairs of astropy
+    Quantities representing the frequency range.  It will ignore the resolution
+    and polarizations.
+    """
+    supports = frequency_support_str.split("U")
+    freq_ranges = [(float(sup.strip('[] ').split("..")[0]),
+                    float(sup.strip('[] ').split("..")[1].split(',')[0].strip(string.letters)))
+                   *u.Unit(sup.strip('[] ').split("..")[1].split(',')[0].strip(string.punctuation+string.digits))
+                   for sup in supports]
+    return freq_ranges
+
+def approximate_primary_beam_sizes(frequency_support_str, dish_diameter=12*u.m, first_null=1.220):
+    """
+    Using parse_frequency_support, determine the mean primary beam size in each
+    observed band
+
+    Parameters
+    ----------
+    frequency_support_str : str
+        The frequency support string, see `parse_frequency_support`
+    dish_diameter : `~astropy.units.Quantity`
+        Meter-equivalent unit.  The diameter of the dish.
+    first_null : float
+        The position of the first null of an Airy.  Used to compute resolution
+        as :math:`R = 1.22 \lambda/D`
+    """
+    freq_ranges = parse_frequency_support(frequency_support_str)
+    beam_sizes = [(first_null*fr.mean().to(u.m, u.spectral())/(dish_diameter)).to(u.arcsec,
+                                                                     u.dimensionless_angles())
+                  for fr in freq_ranges]
+    return beam_sizes
