@@ -14,6 +14,10 @@ class Conf(_config.ConfigNamespace):
         50,
         'Maximum number of rows returned (set to -1 for unlimited).'
         )
+    username = _config.ConfigItem(
+        "",
+        'Optional default username for ESO archive.'
+        )
 
 conf = Conf()
 
