@@ -28,16 +28,17 @@ def _check_response(content):
 
     If all is OK, return True
     """
-    if "NETWORKPROBLEM" in content:
+    if b"NETWORKPROBLEM" in content:
         raise RemoteServiceError("The query resulted in a network "
                                  "problem; the service may be offline.")
-    elif "# No data returned !" not in content:
+    elif b"# No data returned !" not in content:
         return True
 
 
 class EsoClass(QueryWithLogin):
 
     ROW_LIMIT = conf.row_limit
+    USERNAME = conf.username
 
     def __init__(self):
         super(EsoClass, self).__init__()
@@ -84,15 +85,14 @@ class EsoClass(QueryWithLogin):
             tag_name = form_elem.name
             key = form_elem.get('name')
             if tag_name == 'input':
-                if 'type' in form_elem.attrs:
-                    is_file = form_elem.get('type') == 'file'
-                if form_elem.has_attr('checked'):
-                    if form_elem.has_attr('value'):
-                        value = form_elem.get('value')
+                is_file = (form_elem.get('type') == 'file')
+                value = form_elem.get('value')
+                if form_elem.get('type') == 'checkbox':
+                    if form_elem.has_attr('checked'):
+                        if not value:
+                            value = 'on'
                     else:
-                        value = 'on'
-                else:
-                    value = form_elem.get('value')
+                        value = None
             elif tag_name == 'select':
                 if form_elem.get('multiple') is not None:
                     value = []
@@ -129,6 +129,7 @@ class EsoClass(QueryWithLogin):
 
         # for future debugging
         self._payload = payload
+        log.debug("Form: payload={0}".format(payload))
 
         if method is not None:
             fmt = method
@@ -145,7 +146,12 @@ class EsoClass(QueryWithLogin):
 
         return response
 
-    def _login(self, username):
+    def _login(self, username=None, store_password=False):
+        if username is None:
+            if self.USERNAME == "":
+                raise LoginError("If you do not pass a username to login(), you should configure a default one!")
+            else:
+                username = self.USERNAME
         # Get password from keyring or prompt
         password_from_keyring = keyring.get_password("astroquery:www.eso.org", username)
         if password_from_keyring is None:
@@ -170,7 +176,7 @@ class EsoClass(QueryWithLogin):
         else:
             log.exception("Authentication failed!")
         # When authenticated, save password in keyring if needed
-        if authenticated and password_from_keyring is None:
+        if authenticated and password_from_keyring is None and store_password:
             keyring.set_password("astroquery:www.eso.org", username, password)
         return authenticated
 
@@ -196,7 +202,7 @@ class EsoClass(QueryWithLogin):
                     instrument = href.split("/")[-2]
                     if instrument not in self._instrument_list:
                         self._instrument_list.append(instrument)
-            self._instrument_list.append('harps')
+            self._instrument_list.append(u'harps')
         return self._instrument_list
 
     def list_surveys(self, cache=True):
@@ -259,17 +265,18 @@ class EsoClass(QueryWithLogin):
         survey_response = self._activate_form(survey_form, form_index=0,
                                               inputs=query_dict, cache=cache)
 
-        content = survey_response.text
-        byte_content = survey_response.content
+        content = survey_response.content
+        #First line is always garbage
+        content = content.split(b'\n',1)[1]
+        log.debug("Response content:\n{0}".format(content))
         if _check_response(content):
             try:
-                table = Table.read(BytesIO(byte_content), format="ascii.csv",
-                                   guess=False, header_start=1)
+                table = Table.read(BytesIO(content), format="ascii.csv", comment="^#")
             except Exception as ex:
                 # astropy 0.3.2 raises an anonymous exception; this is
                 # intended to prevent that from causing real problems
                 if 'No reader defined' in ex.args[0]:
-                    table = Table.read(BytesIO(byte_content), format="ascii",
+                    table = Table.read(BytesIO(content), format="ascii",
                                        delimiter=',', guess=False,
                                        header_start=1)
                 else:
@@ -342,16 +349,11 @@ class EsoClass(QueryWithLogin):
             instrument_response = self._activate_form(instrument_form,
                                                       form_index=0,
                                                       inputs=query_dict, cache=cache)
-            text = instrument_response.text
-            byte_content = instrument_response.content
-            if _check_response(text):
-                content = []
-                # The first line is garbage, don't know why
-                for line in byte_content.split(b'\n')[1:]:
-                    if len(line) > 0:  # Drop empty lines
-                        if line[0:1] != b'#':  # And drop comments
-                            content += [line]
-                content = b'\n'.join(content)
+            content = instrument_response.content
+            #First line is always garbage
+            content = content.split(b'\n', 1)[1]
+            log.debug("Response content:\n{0}".format(content))
+            if _check_response(content):
                 try:
                     table = Table.read(BytesIO(content), format="ascii.csv", comment='^#')
                 except Exception as ex:
@@ -459,7 +461,7 @@ class EsoClass(QueryWithLogin):
 
         Returns
         -------
-        files : list of strings
+        files : list of strings or string
             List of files that have been locally downloaded from the archive.
 
         Examples
@@ -473,7 +475,10 @@ class EsoClass(QueryWithLogin):
         files = []
 
         if isinstance(datasets, six.string_types):
+            return_list = False
             datasets = [datasets]
+        else:
+            return_list = True
         if not isinstance(datasets, (list, tuple, np.ndarray)):
             raise TypeError("Datasets must be given as a list of strings.")
 
@@ -493,6 +498,9 @@ class EsoClass(QueryWithLogin):
             elif os.path.exists(local_filename + ".Z"):
                 log.info("Found {0}.fits.Z...".format(dataset))
                 files.append(local_filename + ".Z")
+            elif os.path.exists(local_filename + ".fz"):  # RICE-compressed
+                log.info("Found {0}.fits.fz...".format(dataset))
+                files.append(local_filename + ".fz")
             else:
                 datasets_to_download.append(dataset)
 
@@ -503,6 +511,8 @@ class EsoClass(QueryWithLogin):
 
         # Second: Download the other datasets
         if datasets_to_download:
+            if not self.authenticated():
+                self.login()
             data_retrieval_form = self._request("GET",
                                                 "http://archive.eso.org/cms/eso-data/eso-data-direct-retrieval.html",
                                                 cache=cache)
@@ -539,11 +549,13 @@ class EsoClass(QueryWithLogin):
                                              " perhaps the requested file could not be found?")
             log.info("Downloading files...")
             for fileId in root.select('input[name=fileId]'):
-                fileLink = fileId.attrs['value'].split()[1]
-                fileLink = fileLink.replace("/api", "").replace("https://", "http://")
+                fileLink = "http://dataportal.eso.org/dataPortal"+fileId.attrs['value'].split()[1]
                 filename = self._request("GET", fileLink, save=True)
                 files.append(system_tools.gunzip(filename))
+        self._session.redirect_cache.clear() # EMpty the redirect cache of this request session
         log.info("Done!")
+        if (not return_list) and (len(files)==1):
+            files = files[0]
         return files
 
     def verify_data_exists(self, dataset):
@@ -562,8 +574,8 @@ class EsoClass(QueryWithLogin):
 
         return 'No data returned' not in content
 
-    def query_apex_quicklooks(self, project_id, help=False, open_form=False,
-                              cache=True, **kwargs):
+    def query_apex_quicklooks(self, project_id=None, help=False,
+                              open_form=False, cache=True, **kwargs):
         """
         APEX data are distributed with quicklook products identified with a
         different name than other ESO products.  This query tool searches by
@@ -584,26 +596,32 @@ class EsoClass(QueryWithLogin):
             return self._print_help(apex_query_url, 'apex')
         else:
 
-            payload = {'dp_id':project_id, 'wdbo':'csv/download'}
+            payload = {'wdbo':'csv/download'}
+            if project_id is not None:
+                payload['dp_id'] = project_id
+            payload.update(kwargs)
 
             apex_form = self._request("GET", apex_query_url, cache=cache)
             apex_response = self._activate_form(apex_form, form_index=0,
                                                 inputs=payload, cache=cache,
                                                 method='application/x-www-form-urlencoded')
 
-            content = apex_response.text
-            byte_content = apex_response.content
+            content = apex_response.content
             if _check_response(content):
+                #First line is always garbage
+                content = content.split(b'\n',1)[1]
                 try:
-                    table = Table.read(BytesIO(byte_content), format="ascii.csv",
-                                       guess=False, header_start=1)
+                    table = Table.read(BytesIO(content), format="ascii.csv",
+                                       guess=False,# header_start=1,
+                                       comment="#")
                 except Exception as ex:
                     # astropy 0.3.2 raises an anonymous exception; this is
                     # intended to prevent that from causing real problems
                     if 'No reader defined' in ex.args[0]:
-                        table = Table.read(BytesIO(byte_content), format="ascii",
+                        table = Table.read(BytesIO(content), format="ascii",
                                            delimiter=',', guess=False,
-                                           header_start=1)
+                                           #header_start=1,
+                                           comment="#")
                     else:
                         raise ex
             else:
@@ -624,7 +642,7 @@ class EsoClass(QueryWithLogin):
 
         resp = self._request("GET", url, cache=cache)
         doc = BeautifulSoup(resp.content, 'html5lib')
-        form = doc.select("html > body > form > pre")[0]
+        form = doc.select("html body form pre")[0]
         for section in form.select("table"):
             section_title = "".join(section.stripped_strings)
             section_title = "\n".join(["", section_title, "-"*len(section_title)])
