@@ -3,7 +3,8 @@
 Custom exceptions used in the astroquery query classes
 """
 
-__all__ = ['TimeoutError', 'InvalidQueryError', 'RemoteServiceError', 'TableParseError']
+__all__ = ['TimeoutError', 'InvalidQueryError', 'RemoteServiceError',
+           'TableParseError', 'LoginError']
 
 
 class TimeoutError(Exception):
@@ -18,17 +19,27 @@ class TimeoutError(Exception):
 class InvalidQueryError(Exception):
     pass
 
+
 class TableParseError(Exception):
     """
-    Errors related to VOTable parsing.  
+    Errors related to VOTable parsing.
     These should be either submitted as issues to astropy or to the originating
     service.
     """
     pass
 
+
 class RemoteServiceError(Exception):
     """
     Errors related to the remote service, i.e. if the service returns an error
     page
     """
     pass
+
+
+class LoginError(Exception):
+    """
+    Errors due to failed logins.  Should only be raised for services for which
+    a login is a prerequisite for the requested action
+    """
+    pass
