@@ -17,7 +17,6 @@ class GAMAClass(BaseQuery):
     """
 
     request_url = 'http://www.gama-survey.org/dr2/query/'
-    result_relative_url_re = re.compile(r'Download the result file: <a href="(\.\./tmp/.*?)">')
     timeout = 60
 
     def query_sql_async(self, *args, **kwargs):
@@ -38,12 +37,8 @@ class GAMAClass(BaseQuery):
                                       payload,
                                       self.timeout)
 
-        re_result = self.result_relative_url_re.findall(result.text)
-
-        if len(re_result) == 0:
-            raise ValueError("Results did not contain a result url")
-        else:
-            result_url = os.path.join(self.request_url, re_result[0])
+        result_url_relative = find_data_url(result.text)
+        result_url = os.path.join(self.request_url, result_url_relative)
 
         return result_url
 
@@ -81,4 +76,12 @@ def get_gama_datafile(result, **kwargs):
     hdulist = fitsfile.get_fits()
     return Table(hdulist[1].data)
 
+def find_data_url(result_page):
+    """Find and return the URL of the data, given a results page."""
+    result_relative_url_re = re.compile(r'Download the result file: <a href="(\.\./tmp/.*?)">')
+    re_result = result_relative_url_re.findall(result_page)
+    if len(re_result) == 0:
+        raise ValueError("Results did not contain a result url")
+    return re_result[0]
+
 
