@@ -39,9 +39,9 @@ class TestIrsa:
         assert isinstance(result, Table)
 
     def test_query_region_async_polygon(self):
-        polygon = [coord.ICRS(ra=10.1, dec=10.1, unit=(u.deg, u.deg)),
-                   coord.ICRS(ra=10.0, dec=10.1, unit=(u.deg, u.deg)),
-                   coord.ICRS(ra=10.0, dec=10.0, unit=(u.deg, u.deg))]
+        polygon = [coord.SkyCoord(ra=10.1, dec=10.1, unit=(u.deg, u.deg)),
+                   coord.SkyCoord(ra=10.0, dec=10.1, unit=(u.deg, u.deg)),
+                   coord.SkyCoord(ra=10.0, dec=10.0, unit=(u.deg, u.deg))]
         response = irsa.core.Irsa.query_region_async("m31", catalog="fp_psc", spatial="Polygon",
                                                  polygon=polygon)
         assert response is not None
