@@ -6,5 +6,6 @@ def get_package_data():
     paths = [os.path.join('data', '*.xml'),
              os.path.join('data', '*.fits'),
              os.path.join('data', '*.tbl'),
-             os.path.join('data', '*.txt')]
+             os.path.join('data', '*.txt'),
+             ]
     return {'astroquery.irsa_dust.tests': paths}
