@@ -7,13 +7,16 @@ import hashlib
 import os
 import warnings
 import requests
+import itertools
 
 from astropy.extern import six
 from astropy.config import paths
 from astropy import log
-from astropy.utils.console import ProgressBar
+from astropy.utils.console import ProgressBar,ProgressBarOrSpinner
 import astropy.utils.data
 
+from . import version
+
 __all__ = ['BaseQuery', 'QueryWithLogin']
 
 
@@ -96,7 +99,10 @@ class BaseQuery(object):
     """
 
     def __init__(self):
-        self._session = requests.session()
+        S = self._session = requests.session()
+        S.headers['User-Agent'] = ('astroquery/{vers} {olduseragent}'
+                                   .format(vers=version.version,
+                                           olduseragent=S.headers['User-Agent']))
         self.cache_location = os.path.join(paths.get_cache_dir(), 'astroquery',
                                            self.__class__.__name__.split("Class")[0])
         if not os.path.exists(self.cache_location):
@@ -180,19 +186,22 @@ class BaseQuery(object):
         if 'content-length' in response.headers:
             length = int(response.headers['content-length'])
         else:
-            length = 1
-
-        pb = ProgressBar(length)
+            length = None
 
         blocksize = astropy.utils.data.conf.download_block_size
 
         bytes_read = 0
 
-        with open(local_filepath, 'wb') as f:
-            for block in response.iter_content(blocksize):
-                f.write(block)
-                bytes_read += blocksize
-                pb.update(bytes_read if bytes_read <= length else length)
+        with ProgressBarOrSpinner(length,
+                                  'Downloading URL {0} ...'.format(url)) as pb:
+            with open(local_filepath, 'wb') as f:
+                for block in response.iter_content(blocksize):
+                    f.write(block)
+                    bytes_read += blocksize
+                    if length is not None:
+                        pb.update(bytes_read if bytes_read <= length else length)
+                    else:
+                        pb.update(bytes_read)
 
         response.close()
 
