@@ -115,6 +115,7 @@ class SimbadClass(BaseQuery):
     _VOTABLE_FIELDS = ['main_id', 'coordinates']
 
     def __init__(self):
+        super(SimbadClass, self).__init__()
         self._VOTABLE_FIELDS = copy.copy(self._VOTABLE_FIELDS)
 
     def list_wildcards(self):
@@ -161,11 +162,16 @@ class SimbadClass(BaseQuery):
                                           (os.path.join('data',
                                                         'votable_fields_table.txt')),
                                          format='ascii')
-        print (votable_fields_table)
+        print("Available VOTABLE fields: ")
+        print(votable_fields_table)
 
         print("\nFor more information on a field :\nSimbad.get_field_description "
               "('field_name')")
 
+        print()
+        print("Currently active VOTABLE fields:")
+        print(self._VOTABLE_FIELDS)
+
     def get_field_description(self, field_name):
         """
         Displays a description of the VOTable field.
@@ -677,7 +683,7 @@ class SimbadClass(BaseQuery):
             ra, dec, frame = _parse_coordinates(coordinates)
             args = [ra, dec]
             kwargs['frame'] = frame
-            if kwargs.get('radius'):
+            if kwargs.get('radius') is not None:
                 kwargs['radius'] = _parse_radius(kwargs['radius'])
         # rename equinox to equi as required by SIMBAD script
         if kwargs.get('equinox'):
@@ -780,7 +786,11 @@ def _parse_radius(radius):
     try:
         angle = commons.parse_radius(radius)
         # find the most appropriate unit - d, m or s
-        index = min([i for (i, val) in enumerate(angle.dms) if int(val) > 0])
+        nonzero_indices = [i for (i, val) in enumerate(angle.dms) if int(val) > 0]
+        if len(nonzero_indices) > 0:
+            index = min(nonzero_indices)
+        else:
+            index = 2  # use arcseconds when radius smaller than 1 arcsecond
         unit = ('d', 'm', 's')[index]
         if unit == 'd':
             return str(int(angle.degree)) + unit
@@ -882,17 +892,20 @@ class SimbadResult(object):
 class SimbadVOTableResult(SimbadResult):
     """VOTable-type Simbad result"""
     def __init__(self, txt, verbose=False, pedantic=False):
-        SimbadResult.__init__(self, txt, verbose=verbose)
         self.__pedantic = pedantic
         self.__table = None
-        if not self.verbose:
+        if not verbose:
             commons.suppress_vo_warnings()
+        super(SimbadVOTableResult, self).__init__(txt, verbose=verbose)
 
 
     @property
     def table(self):
         if self.__table is None:
-            self.__table = votable.parse_single_table(BytesIO(self.data.encode('utf8')), pedantic=False).to_table()
+            self.bytes = BytesIO(self.data.encode('utf8'))
+            tbl = votable.parse_single_table(self.bytes, pedantic=False)
+            self.__table = tbl.to_table()
+            self.__table.convert_bytestring_to_unicode()
         return self.__table
 
 bibcode_regex = re.compile(r'query\s+bibcode\s+(wildcard)?\s+([\w]*)')
