@@ -2,12 +2,20 @@
 from astropy.tests.helper import remote_data
 
 from ...skyview import SkyView
+from .test_skyview import data_path
 
 
 @remote_data
 def test_get_image_list():
-    urls = SkyView().get_image_list(
-        position='Eta Carinae', survey=['Fermi 5', 'HRI', 'DSS'])
+    urls = SkyView().get_image_list(position='Eta Carinae',
+                                    survey=['Fermi 5', 'HRI', 'DSS'])
     assert len(urls) == 3
     for url in urls:
         assert url.startswith('http://skyview.gsfc.nasa.gov/tempspace/fits/')
+
+@remote_data
+def test_survey_list():
+    with open(data_path('survey_dict.txt'),'r') as f:
+        survey_dict = eval(f.read())
+
+    assert SkyView.survey_dict == survey_dict
