@@ -8,12 +8,13 @@ import functools
 
 __all__ = ["class_or_instance"]
 
+
 class class_or_instance(object):
 
     def __init__(self, fn):
         self.fn = fn
 
-        if hasattr(fn,'__doc__'):
+        if hasattr(fn, '__doc__'):
             self.__doc__ = fn.__doc__
         else:
             self.__doc__ = ""
@@ -25,3 +26,15 @@ class class_or_instance(object):
             f = lambda *args, **kwds: self.fn(cls, *args, **kwds)
         functools.update_wrapper(f, self.fn)
         return f
+
+
+class property_class_or_instance(property):
+
+    def __get__(self, obj, cls):
+        if obj is not None:
+            return self.fget(obj)
+        else:
+            return self.fget(cls)
+
+    def __set__(self, *args):
+        raise ValueError("Setters don't work.")
