@@ -49,7 +49,7 @@ def test_class_or_instance():
 
 
 @pytest.mark.parametrize(('coordinates'),
-                         [coord.ICRS(ra=148, dec=69, unit=(u.deg, u.deg)),
+                         [coord.SkyCoord(ra=148, dec=69, unit=(u.deg, u.deg)),
                           ]
                          )
 def test_parse_coordinates_1(coordinates):
@@ -85,14 +85,20 @@ def test_parse_radius_2(radius):
 
 
 def test_send_request_post(monkeypatch):
-    def mock_post(url, data, timeout, headers={}):
+    def mock_post(url, data, timeout, headers={}, status_code=200):
         class SpecialMockResponse(object):
 
-            def __init__(self, url, data, headers):
+            def __init__(self, url, data, headers, status_code):
                 self.url = url
                 self.data = data
                 self.headers = headers
-        return SpecialMockResponse(url, data, headers=headers)
+                self.status_code = status_code
+
+            def raise_for_status(self):
+                pass
+
+        return SpecialMockResponse(url, data, headers=headers,
+                                   status_code=status_code)
     monkeypatch.setattr(requests, 'post', mock_post)
 
     response = commons.send_request('https://github.com/astropy/astroquery',
@@ -103,8 +109,10 @@ def test_send_request_post(monkeypatch):
 
 
 def test_send_request_get(monkeypatch):
-    def mock_get(url, params, timeout, headers={}):
+    def mock_get(url, params, timeout, headers={}, status_code=200):
         req = requests.Request('GET', url, params=params, headers=headers).prepare()
+        req.status_code = status_code
+        req.raise_for_status = lambda: None
         return req
     monkeypatch.setattr(requests, 'get', mock_get)
     response = commons.send_request('https://github.com/astropy/astroquery',
@@ -113,8 +121,10 @@ def test_send_request_get(monkeypatch):
 
 
 def test_quantity_timeout(monkeypatch):
-    def mock_get(url, params, timeout, headers={}):
+    def mock_get(url, params, timeout, headers={}, status_code=200):
         req = requests.Request('GET', url, params=params, headers=headers).prepare()
+        req.status_code = status_code
+        req.raise_for_status = lambda: None
         return req
     monkeypatch.setattr(requests, 'get', mock_get)
     response = commons.send_request('https://github.com/astropy/astroquery',
